<?php

namespace Drupal\eca_condition\Plugin\Condition;

use Drupal\Core\Condition\ConditionPluginBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a 'Taxonomy Vocabulary' condition.
 *
 * @Condition(
 *   id = "eca_condition",
 *   label = @Translation("ECA Condition")
 * )
 */
class ECACondition extends ConditionPluginBase {

  /**
   * Conditions key.
   */
  const CONDITIONS = 'eca_conditions';

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      self::CONDITIONS => '',
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function evaluate() {
    $conditions = $this->configuration[self::CONDITIONS];
    if (!mb_strlen(trim($conditions))) {
      return FALSE;
    }

    $conditions = preg_split("/\r?\n/", $conditions);
    foreach ($conditions as $condition) {
      $result = _eca_condition_hook_handler()->condition($condition);
      if (!$result) {
        return FALSE;
      }
    }

    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form[self::CONDITIONS] = [
      '#type' => 'textarea',
      '#required' => FALSE,
      '#title' => $this->t('Conditions'),
      '#description' => $this->t('List of ECA condition event'),
      '#cols' => 60,
      '#rows' => 5,
      '#default_value' => $this->configuration[self::CONDITIONS] ?? '',
    ];

    $form = parent::buildConfigurationForm($form, $form_state);
    $form['negate']['#access'] = FALSE;

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration[self::CONDITIONS] = $form_state->getValue(self::CONDITIONS);
    parent::submitConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function summary() {
    return $this->getPluginDefinition()['label'];
  }

}
