<?php

namespace Drupal\eca_condition\Plugin\ECA\Event;

use Drupal\Core\Form\FormStateInterface;
use Drupal\eca\Attributes\Token;
use Drupal\eca\Event\Tag;
use Drupal\eca\Plugin\ECA\Event\EventBase;
use Drupal\eca_condition\Events\ConditionEvent;

/**
 * Plugin implementation of the ECA Condition for config.
 *
 * @EcaEvent(
 *   id = "eca_condition",
 *   deriver = "Drupal\eca_condition\Plugin\ECA\Event\ECAConditionEventDeriver"
 * )
 */
class ECAConditionEvent extends EventBase {

  /**
   * {@inheritdoc}
   */
  public static function definitions(): array {
    return [
      'condition_event' => [
        'label' => t('ECA Condition'),
        'event_name' => ConditionEvent::CONDITION_EVENT,
        'event_class' => ConditionEvent::class,
        'tags' => Tag::RUNTIME,
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    if ($this->eventClass() === ConditionEvent::class) {
      $values = [
        'condition_id' => '',
      ];
    }
    else {
      $values = [];
    }
    return $values + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    if ($this->eventClass() === ConditionEvent::class) {
      $markup = $this->t('This event provides tokens: "[condition_id]".');
      $form['help'] = [
        '#type' => 'markup',
        '#markup' => $markup,
        '#weight' => 10,
        '#description' => $markup,
      ];
    }
    return $form;
  }

}
